@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2024 Zabbix SIA
+** Copyright (C) 2001-2026 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -433,7 +433,7 @@ func (ch *connHandler) readExpected(path string, timeout time.Duration) parsedRe
 }
 
 func (ch *connHandler) getCollection(glow []byte) (ember.ElementCollection, []string, error) {
-	el := ember.NewElementConnection()
+	el := ember.NewElementCollection()
 
 	err := el.Populate(asn1.NewDecoder(glow))
 	if err != nil {
